# HyFI: Hydra Fast Interface

[![pypi-image]][pypi-url]
[![version-image]][release-url]
[![release-date-image]][release-url]
[![license-image]][license-url]
[![codecov][codecov-image]][codecov-url]
[![codefactor][codefactor-image]][codefactor-url]
[![codacy][codacy-image]][codacy-url]

<!-- Links: -->

[codecov-image]: https://codecov.io/gh/entelecheia/hyfi/branch/main/graph/badge.svg?token=HCYTYW1WVF
[codecov-url]: https://codecov.io/gh/entelecheia/hyfi
[pypi-image]: https://img.shields.io/pypi/v/hyfi
[license-image]: https://img.shields.io/github/license/entelecheia/hyfi
[license-url]: https://github.com/entelecheia/hyfi/blob/main/LICENSE
[version-image]: https://img.shields.io/github/v/release/entelecheia/hyfi?sort=semver
[release-date-image]: https://img.shields.io/github/release-date/entelecheia/hyfi
[release-url]: https://github.com/entelecheia/hyfi/releases
[codefactor-image]: https://www.codefactor.io/repository/github/entelecheia/hyfi/badge
[codefactor-url]: https://www.codefactor.io/repository/github/entelecheia/hyfi
[codacy-image]: https://app.codacy.com/project/badge/Grade/6be6d2ecfbfe40b9ab8490ca25327a96
[codacy-url]: https://app.codacy.com/gh/entelecheia/hyfi/dashboard?utm_source=github.com&utm_medium=referral&utm_content=entelecheia/hyfi&utm_campaign=Badge_grade
[repo-url]: https://github.com/entelecheia/hyfi
[pypi-url]: https://pypi.org/project/hyfi
[docs-url]: https://hyfi.entelecheia.ai
[changelog]: https://github.com/entelecheia/hyfi/blob/main/CHANGELOG.md
[contributing guidelines]: https://github.com/entelecheia/hyfi/blob/main/CONTRIBUTING.md

<!-- Links: -->

Hydra Fast Interface (Hydra and Pydantic based interface framework)

- Documentation: [https://hyfi.entelecheia.ai][docs-url]
- GitHub: [https://github.com/entelecheia/hyfi][repo-url]
- PyPI: [https://pypi.org/project/hyfi][pypi-url]

HyFI is a framework for building interfaces for Python applications. It is based on [Hydra](https://hydra.cc) and [Pydantic](https://docs.pydantic.dev/latest/) and provides a set of tools to build interfaces for Python applications.

## Changelog

See the [CHANGELOG] for more information.

## Contributing

Contributions are welcome! Please see the [contributing guidelines] for more information.

## License

This project is released under the [MIT License][license-url].
